pub struct BehaviorScenario {
pub schema_version: SchemaVersion,
pub id: String,
pub title: String,
pub contract_id: Option<String>,
pub given: Vec<String>,
pub when: Vec<String>,
pub then: Vec<String>,
pub tags: Vec<String>,
}Expand description
A BDD-style behavior scenario for readable intent documentation.
Behavior scenarios complement contracts by providing narrative descriptions of expected behavior, useful for acceptance testing and communicating intent to stakeholders.
Stored at specs/behavior/<id>.toml.
Fields
schema_version: SchemaVersionid: StringUnique identifier for this scenario.
title: Stringcontract_id: Option<String>Optional contract this scenario relates to.
given: Vec<String>Preconditions (Given).
when: Vec<String>Actions (When).
then: Vec<String>Expected outcomes (Then).
Tags for categorization.