pub fn validate_version(version: &SchemaVersion) -> SpecResult<()>Expand description
Validate that a schema version is compatible with the current version.
pub fn validate_version(version: &SchemaVersion) -> SpecResult<()>Validate that a schema version is compatible with the current version.